==> apgl-0.6.tar.gz: apgl-0.6/apgl/generator/test/BarabasiAlbertGeneratorTest.py <==

import unittest
import numpy

from apgl.generator.BarabasiAlbertGenerator import BarabasiAlbertGenerator
from apgl.graph.VertexList import VertexList
from apgl.graph.SparseGraph import SparseGraph

class  BarabasiAlbertGeneratorTest(unittest.TestCase):
    def testGenerateGraph(self):
        numFeatures = 1
        numVertices = 20

        vList = VertexList(numVertices, numFeatures)
        graph = SparseGraph(vList)

        ell = 2
        m = 0
        generator = BarabasiAlbertGenerator(graph)

        graph = generator.generateGraph(ell, m)
        self.assertEquals(graph.getNumEdges(), 0)

        ell = 5
        graph.removeAllEdges()
        graph = generator.generateGraph(ell, m)
        self.assertEquals(graph.getNumEdges(), 0)

        #Now test case where we m != 0
        ell = 2
        m = 1
        graph.removeAllEdges()
        graph = generator.generateGraph(ell, m)
        self.assertEquals(graph.getNumEdges(), (numVertices-ell)*m)

        m = 2
        graph.removeAllEdges()
        graph = generator.generateGraph(ell, m)
        self.assertEquals(graph.getNumEdges(), (numVertices-ell)*m)


    def testGraphDisplay(self):
        try:
            import networkx
            import matplotlib
        except ImportError as error:
            print(error)
            return 

        #Show
        numFeatures = 1
        numVertices = 20

        vList = VertexList(numVertices, numFeatures)
        graph = SparseGraph(vList)

        ell = 2
        m = 2
        generator = BarabasiAlbertGenerator(graph)

        graph = generator.generateGraph(ell, m)

        print(graph.degreeDistribution())

        nxGraph = graph.toNetworkXGraph()
        nodePositions = networkx.spring_layout(nxGraph)
        nodesAndEdges = networkx.draw_networkx(nxGraph, pos=nodePositions)
        matplotlib.pyplot.show()

if __name__ == '__main__':
    unittest.main()

==> apgl-0.6.1.tar.gz: apgl-0.6.1/apgl/generator/test/BarabasiAlbertGeneratorTest.py <==

import unittest

from apgl.generator.BarabasiAlbertGenerator import BarabasiAlbertGenerator
from apgl.graph.VertexList import VertexList
from apgl.graph.SparseGraph import SparseGraph

class  BarabasiAlbertGeneratorTest(unittest.TestCase):
    def testGenerate(self):
        numFeatures = 1
        numVertices = 20

        vList = VertexList(numVertices, numFeatures)
        graph = SparseGraph(vList)

        ell = 2
        m = 0
        generator = BarabasiAlbertGenerator(ell, m)

        graph = generator.generate(graph)
        self.assertEquals(graph.getNumEdges(), 0)

        ell = 5
        graph.removeAllEdges()
        generator.setEll(ell)
        graph = generator.generate(graph)
        self.assertEquals(graph.getNumEdges(), 0)

        #Now test case where we m != 0
        ell = 2
        m = 1
        graph.removeAllEdges()
        generator.setEll(ell)
        generator.setM(m)
        graph = generator.generate(graph)
        self.assertEquals(graph.getNumEdges(), (numVertices-ell)*m)

        m = 2
        graph.removeAllEdges()
        generator.setM(m)
        graph = generator.generate(graph)
        self.assertEquals(graph.getNumEdges(), (numVertices-ell)*m)


    def testGraphDisplay(self):
        try:
            import networkx
            import matplotlib
        except ImportError as error:
            print(error)
            return 

        #Show
        numFeatures = 1
        numVertices = 20

        vList = VertexList(numVertices, numFeatures)
        graph = SparseGraph(vList)

        ell = 2
        m = 2
        generator = BarabasiAlbertGenerator(ell, m)

        graph = generator.generate(graph)

        print(graph.degreeDistribution())

        nxGraph = graph.toNetworkXGraph()
        nodePositions = networkx.spring_layout(nxGraph)
        nodesAndEdges = networkx.draw_networkx(nxGraph, pos=nodePositions)
        matplotlib.pyplot.show()

if __name__ == '__main__':
    unittest.main()
